==> DateTime-Locale-1.41.tar.gz: DateTime-Locale-1.41/share/hi-Latn-IN.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E, h:mm B",
    EBhms => "E, h:mm:ss B",
    EHm => "E, HH:mm",
    EHms => "E, HH:mm:ss",
    Ed => "E d",
    Ehm => "E, h:mm\N{U+202f}a",
    "Ehm-alt-ascii" => "E, h:mm a",
    Ehms => "E, h:mm:ss\N{U+202f}a",
    "Ehms-alt-ascii" => "E, h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEEEEd => "EEEE d MMM, y G",
    GyMMMEd => "G y, dd MMM, E",
    GyMMMd => "G y, d MMM",
    GyMd => "d/M/y G",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, dd/MM",
    MMM => "LLL",
    MMMEEEEd => "EEEE d MMM",
    MMMEd => "E, d MMM",
    MMMMEEEEd => "EEEE d MMMM",
    "MMMMW-count-one" => "MMMM 'kaa' 'week' W",
    "MMMMW-count-other" => "MMMM 'kaa' 'week' W",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    MMdd => "dd/MM",
    Md => "dd/MM",
    d => "d",
    h => "h\N{U+202f}a",
    "h-alt-ascii" => "h a",
    hm => "h:mm\N{U+202f}a",
    "hm-alt-ascii" => "h:mm a",
    hms => "h:mm:ss\N{U+202f}a",
    "hms-alt-ascii" => "h:mm:ss a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    "hmsv-alt-ascii" => "h:mm:ss a v",
    hmv => "h:mm\N{U+202f}a v",
    "hmv-alt-ascii" => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "MM/y",
    yMEd => "E, d/M/y",
    yMMM => "MMM y",
    yMMMEEEEd => "EEEE d MMM, y",
    yMMMEd => "E, d MMM, y",
    yMMMM => "MMMM y",
    yMMMMEEEEd => "EEEE d MMMM, y",
    yMMMd => "d MMM, y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "Y 'kaa' 'week' w",
    "yw-count-other" => "Y 'kaa' 'week' w",
  },
  code => "hi-Latn-IN",
  date_format_full => "EEEE d MMMM, y",
  date_format_long => "d MMMM, y",
  date_format_medium => "dd MMM, y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1}, {0}",
  datetime_format_long => "{1}, {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Som",
    "Mangal",
    "Budh",
    "Guru",
    "Shukra",
    "Shani",
    "Ravi",
  ],
  day_format_narrow => [
    "So",
    "Ma",
    "Bu",
    "Gu",
    "Sh",
    "Sha",
    "Ra",
  ],
  day_format_wide => [
    "Somwaar",
    "Mangalwaar",
    "Budhwaar",
    "Guruwaar",
    "Shukrawaar",
    "Shaniwaar",
    "Raviwaar",
  ],
  day_stand_alone_abbreviated => [
    "Som",
    "Mangal",
    "Budh",
    "Guru",
    "Shukra",
    "Shani",
    "Ravi",
  ],
  day_stand_alone_narrow => [
    "So",
    "Ma",
    "Bu",
    "Gu",
    "Sh",
    "Sha",
    "Ra",
  ],
  day_stand_alone_wide => [
    "Somwaar",
    "Mangalwaar",
    "Budhwaar",
    "Guruwaar",
    "Shukrawaar",
    "Shaniwaar",
    "Raviwaar",
  ],
  era_abbreviated => [
    "BC",
    "AD",
  ],
  era_narrow => [
    "B",
    "A",
  ],
  era_wide => [
    "Before Christ",
    "Anno Domini",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%A %d %B %Y %I:%M:%S %p %Z",
  glibc_date_format => "%d/%m/%y",
  glibc_datetime_format => "%A %d %B %Y %I:%M:%S %p",
  glibc_time_12_format => "%I:%M:%S %p %Z",
  glibc_time_format => "%I:%M:%S %p %Z",
  language => "Hindi",
  month_format_abbreviated => [
    "Jan",
    "Feb",
    "Mar",
    "Apr",
    "May",
    "Jun",
    "Jul",
    "Aug",
    "Sep",
    "Oct",
    "Nov",
    "Dec",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "January",
    "February",
    "March",
    "April",
    "May",
    "June",
    "July",
    "August",
    "September",
    "October",
    "November",
    "December",
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "Feb",
    "Mar",
    "Apr",
    "May",
    "Jun",
    "Jul",
    "Aug",
    "Sept",
    "Oct",
    "Nov",
    "Dec",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "January",
    "February",
    "March",
    "April",
    "May",
    "June",
    "July",
    "August",
    "September",
    "October",
    "November",
    "December",
  ],
  name => "Hindi India Latin",
  native_language => "Hindi",
  native_name => "Hindi India Latin",
  native_script => "Latin",
  native_territory => "India",
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1st quarter",
    "2nd quarter",
    "3rd quarter",
    "4th quarter",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1st quarter",
    "2nd quarter",
    "3rd quarter",
    "4th quarter",
  ],
  script => "Latin",
  territory => "India",
  time_format_full => "h:mm:ss\N{U+202f}a zzzz",
  time_format_long => "h:mm:ss\N{U+202f}a z",
  time_format_medium => "h:mm:ss\N{U+202f}a",
  time_format_short => "h:mm\N{U+202f}a",
  variant => undef,
  version => "44.1",
}

==> DateTime-Locale-1.43.tar.gz: DateTime-Locale-1.43/share/hi-Latn-IN.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E, h:mm B",
    EBhms => "E, h:mm:ss B",
    EHm => "E, HH:mm",
    EHms => "E, HH:mm:ss",
    Ed => "E d",
    Ehm => "E, h:mm\N{U+202f}a",
    "Ehm-alt-ascii" => "E, h:mm a",
    Ehms => "E, h:mm:ss\N{U+202f}a",
    "Ehms-alt-ascii" => "E, h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEEEEd => "EEEE d MMM, y G",
    GyMMMEd => "G y, dd MMM, E",
    GyMMMd => "G y, d MMM",
    GyMd => "d/M/y G",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, dd/MM",
    MMM => "LLL",
    MMMEEEEd => "EEEE d MMM",
    MMMEd => "E, d MMM",
    MMMMEEEEd => "EEEE d MMMM",
    "MMMMW-count-one" => "MMMM 'kaa' 'week' W",
    "MMMMW-count-other" => "MMMM 'kaa' 'week' W",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    MMdd => "dd/MM",
    Md => "dd/MM",
    d => "d",
    h => "h\N{U+202f}a",
    "h-alt-ascii" => "h a",
    hm => "h:mm\N{U+202f}a",
    "hm-alt-ascii" => "h:mm a",
    hms => "h:mm:ss\N{U+202f}a",
    "hms-alt-ascii" => "h:mm:ss a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    "hmsv-alt-ascii" => "h:mm:ss a v",
    hmv => "h:mm\N{U+202f}a v",
    "hmv-alt-ascii" => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "MM/y",
    yMEd => "E, d/M/y",
    yMMM => "MMM y",
    yMMMEEEEd => "EEEE d MMM, y",
    yMMMEd => "E, d MMM, y",
    yMMMM => "MMMM y",
    yMMMMEEEEd => "EEEE d MMMM, y",
    yMMMd => "d MMM, y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "Y 'kaa' 'week' w",
    "yw-count-other" => "Y 'kaa' 'week' w",
  },
  code => "hi-Latn-IN",
  date_format_full => "EEEE d MMMM, y",
  date_format_long => "d MMMM, y",
  date_format_medium => "dd MMM, y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1}, {0}",
  datetime_format_long => "{1}, {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Som",
    "Mangal",
    "Budh",
    "Guru",
    "Shukra",
    "Shani",
    "Ravi",
  ],
  day_format_narrow => [
    "So",
    "Ma",
    "Bu",
    "Gu",
    "Sh",
    "Sha",
    "Ra",
  ],
  day_format_wide => [
    "Somwaar",
    "Mangalwaar",
    "Budhwaar",
    "Guruwaar",
    "Shukrawaar",
    "Shaniwaar",
    "Raviwaar",
  ],
  day_stand_alone_abbreviated => [
    "Som",
    "Mangal",
    "Budh",
    "Guru",
    "Shukra",
    "Shani",
    "Ravi",
  ],
  day_stand_alone_narrow => [
    "So",
    "Ma",
    "Bu",
    "Gu",
    "Sh",
    "Sha",
    "Ra",
  ],
  day_stand_alone_wide => [
    "Somwaar",
    "Mangalwaar",
    "Budhwaar",
    "Guruwaar",
    "Shukrawaar",
    "Shaniwaar",
    "Raviwaar",
  ],
  era_abbreviated => [
    "BC",
    "AD",
  ],
  era_narrow => [
    "B",
    "A",
  ],
  era_wide => [
    "Before Christ",
    "Anno Domini",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%A %d %B %Y %I:%M:%S %p %Z",
  glibc_date_format => "%d/%m/%y",
  glibc_datetime_format => "%A %d %B %Y %I:%M:%S %p",
  glibc_time_12_format => "%I:%M:%S %p %Z",
  glibc_time_format => "%I:%M:%S %p %Z",
  language => "Hindi",
  month_format_abbreviated => [
    "Jan",
    "Feb",
    "Mar",
    "Apr",
    "May",
    "Jun",
    "Jul",
    "Aug",
    "Sep",
    "Oct",
    "Nov",
    "Dec",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "January",
    "February",
    "March",
    "April",
    "May",
    "June",
    "July",
    "August",
    "September",
    "October",
    "November",
    "December",
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "Feb",
    "Mar",
    "Apr",
    "May",
    "Jun",
    "Jul",
    "Aug",
    "Sept",
    "Oct",
    "Nov",
    "Dec",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "January",
    "February",
    "March",
    "April",
    "May",
    "June",
    "July",
    "August",
    "September",
    "October",
    "November",
    "December",
  ],
  name => "Hindi India Latin",
  native_language => "Hindi",
  native_name => "Hindi Bharat Latin",
  native_script => "Latin",
  native_territory => "Bharat",
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1st quarter",
    "2nd quarter",
    "3rd quarter",
    "4th quarter",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1st quarter",
    "2nd quarter",
    "3rd quarter",
    "4th quarter",
  ],
  script => "Latin",
  territory => "India",
  time_format_full => "h:mm:ss\N{U+202f}a zzzz",
  time_format_long => "h:mm:ss\N{U+202f}a z",
  time_format_medium => "h:mm:ss\N{U+202f}a",
  time_format_short => "h:mm\N{U+202f}a",
  variant => undef,
  version => 45,
}
